Crate utf8toipv4

Crate utf8toipv4 

Enums

Error

Functions

ipv4_to_utf8
returns a vector of strings v such that utf8_to_ipv4[s] for each s in v would yield ipv4_addr Note: this is not exhaustive —————————–– | ipv4_addr = {a}.{b}.{c}.{d} | —————————––
is_valid_ipv4_address
determines addr’s validity as ipv4 (4 unsigned integers with .s dividing them)
utf8_to_ipv4
converts each character’s codepoint into base2 (little-endian) and uses all non-zero bytes to return ipv4 address as string special case: if the input string has less than 4 non-zero bytes, the ending will be ended with complementary zeros